import Button from "@/components/UI/Button/Button";
import axiosBase from "@/Config/axiosBase";
import { useState } from "react";
import { ICustomer } from "@/interfaces/checkout";
import { useLocation } from "react-router-dom";
import Spinner from "@/components/UI/Spinner/Spinner";
import "./ContactData.css";

const ContactData = () => {
  const location = useLocation()

  const [loading, setLoading] = useState<boolean>(false)
  const [customer, setCustomer] = useState<ICustomer>({
    name: '',
    email: '',
    street: '',
    postal: ''
  })

  const onChangeCustomer = (e: React.FormEvent<HTMLInputElement>) => {
      const {value, name} = e.currentTarget
      setCustomer(prevState => ({...prevState, [name]: value}))
  }

  const onOrder = async (e: React.SyntheticEvent<HTMLFormElement>) => {
    e.preventDefault()
    setLoading(true)

    const data = {
      contact: customer,
      ingredients: location.state?.ingredients
    }

    try {
      await axiosBase.post('orders.json', data) 
    } catch (error) {
      console.error(error)
    }
    
    setLoading(false)
  }

  if(loading) return <Spinner/>

  return (
    <div className="ContactData">
      <h4>Enter your Contact Data</h4>

      <form onSubmit={onOrder}>
        <input
            className="Input"
            type="text"
            name="name"
            placeholder="Your Name"
            value={customer.name}
            onChange={(e) => onChangeCustomer(e)}
        />

        <input
            className="Input"
            type="email"
            name="email"
            placeholder="Your Mail"
            value={customer.email}
            onChange={(e) => onChangeCustomer(e)}
        />

        <input
            className="Input"
            type="text"
            name="street"
            placeholder="Street"
            value={customer.street}
            onChange={(e) => onChangeCustomer(e)}
        />

        <input
            className="Input"
            type="text"
            name="postal"
            placeholder="Postal Code"
            value={customer.postal}
            onChange={(e) => onChangeCustomer(e)}
        />

        <Button click={() => {}} btnType="Success">
          ORDER
        </Button>
      </form>
    </div>
  );
};

export default ContactData;
